==> cramr_ui_lib-0.0.14.tar.gz: test/widgets/written_indicative_study_widget_test.dart <==
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/widgets/written_indicative_study_widget.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:provider/provider.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';

main() {
  testWidgets('Tightly coupled test of the next person button behaviour',
      (WidgetTester tester) async {
    VerbTestModel model = VerbTestModel();
    model.initialise(_randomIndicative, _randomPronouns, 'fr',
        _randomInfinitive, 'translation');
    await tester.pumpWidget(ChangeNotifierProvider(
        create: (BuildContext context) {
          return model;
        },
        child: const MaterialApp(
          home: WrittenIndicativeStudyWidget(),
        )));
    for (int i = 0; i < _randomPronouns.length; i++) {
      Finder pronounFinder = find.text(_randomPronouns[i]);
      expect(pronounFinder, findsNWidgets(2));
      Finder nextPersonButtonFinder = find.byKey(const Key('nextPersonKey'));
      expect(nextPersonButtonFinder, findsOneWidget);
      String currentEntry = _randomIndicative[i];
      Finder entryFieldFinder = find.byKey(Key('actualVerb_$i'));
      Finder entryValueFinder = find.text(currentEntry);
      expect(entryValueFinder, findsOneWidget);
      await tester.enterText(entryFieldFinder, currentEntry);
      expect(entryValueFinder, findsNWidgets(2));
      await tester.tap(nextPersonButtonFinder);
      await tester.pumpAndSettle();
      expect(entryValueFinder, findsNothing);
    }
  });
}

==> cramr_ui_lib-1.0.16.tar.gz: test/widgets/written_indicative_study_widget_test.dart <==
import 'package:cramr_ui_lib/widgets/written_indicative_study_widget.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

main() {
  testWidgets('Tightly coupled test of the next person button behaviour',
      (WidgetTester tester) async {
    await tester.pumpWidget(MaterialApp(
      home: WrittenIndicativeStudyWidget(
        numberOfItems: 6,
        fullPronouns: _randomPronouns,
        targetLanguage: 'fr',
        expectedIndicative: _randomIndicative,
      ),
    ));
    for (int i = 0; i < _randomPronouns.length; i++) {
      Finder pronounFinder = find.text(_randomPronouns[i]);
      expect(pronounFinder, findsNWidgets(2));
      Finder nextPersonButtonFinder = find.byKey(const Key('nextPersonKey'));
      expect(nextPersonButtonFinder, findsOneWidget);
      String currentEntry = _randomIndicative[i];
      Finder entryFieldFinder = find.byKey(Key('actualVerb_$i'));
      Finder entryValueFinder = find.text(currentEntry);
      expect(entryValueFinder, findsOneWidget);
      await tester.enterText(entryFieldFinder, currentEntry);
      expect(entryValueFinder, findsNWidgets(2));
      await tester.tap(nextPersonButtonFinder);
      await tester.pumpAndSettle();
      expect(entryValueFinder, findsNothing);
    }
  });
}
